@@ -139,6 +139,22 @@
 
 
 
+.Flying <- function() {
+  ##############################################################################
+  # - To the moon
+  ##############################################################################
+
+  cat("
+      ###################################################
+      ###################################################
+      Thank you for flying **rags2ridges**!
+      - Your rags2ridges flight team
+      ###################################################
+      ################################################### \n")
+}
+
+
+
 .rags2logo <- function(){
   ##############################################################################
   # - Logo
